<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Postavke svjetline</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Postavke pozadinskog osvjetljenja i svjetline:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>Pozadinsko osvjetljenje</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation>Svjetlina</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>Zatraži potvrdu nakon mijenjanja postavki</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="54"/>
        <source>Currently unsupported under Wayland</source>
        <translation>Trenutačno nije podržano u Waylandu</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="122"/>
        <source>Brightness settings changed</source>
        <translation>Postavke svjetline su promijenjene</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="123"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Potrebna je potvrda. Jesu li postavke ispravne?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Rezultat:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Increase brightness.</source>
        <translation>Povećaj svjetlinu.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Decrease brightness.</source>
        <translation>Smanji svjetlinu.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>Postavi svjetlinu između 1 i 100.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>Reset gamma to default value.</source>
        <translation>Resetiraj gamut na standardnu vrijednost.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="114"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation>%1: Nije moguće koristiti povećavanje/smanjivanje i postavljanje zajedno</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="119"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation>%1: Nije moguće koristiti opcije povećavanja i smanjivanja zajedno</translation>
    </message>
</context>
</TS>
